Description Usage Arguments Value
A package for computing fast Rcpp-based predictive R-squares, via
the nonparametric bootstrap. Heavy use is made of RcppEigen.
Predictive R-squared statistics use two different samples, one for
training a linear model and one for validating it. The
bootR2 package draws two nonparametric bootstrap samples to
be used as training and validation data for calculating a
predictive R-squared. Such a bootstrap distribution provides a
better assessment of the proportion of variation that the fitted
model could explain in other samples from the population. NOTE:
the adjusted R-squared does *not* provide this assessment.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | bootR2(object, ...)
## Default S3 method:
bootR2(object, ...)
## S3 method for class 'lm'
bootR2(object, nBoot = 1, predictive = TRUE, ...)
## S3 method for class 'matrix'
bootR2(object, y, nBoot = 1, predictive = TRUE, ...)
## S3 method for class 'numeric'
bootR2(object, X, nBoot = 1, predictive = TRUE, ...)
bootR2pred(X, y, nBoot)
bootR2samp(X, y, nBoot)
|
object |
Object for calculating R-squared |
... |
Not currently used |
nBoot |
Number of bootstrap samples |
predictive |
Should the predictive (i.e. double) bootstrap be
used? If |
X |
model matrix |
y |
model response |
Vector of R-squared bootstrap samples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.